@@ -9,18 +9,20 @@ the Twitter APIs, with a method to upload a media
 
 import asyncio
 import io
-from contextlib import suppress
 import logging
-
-try:
-    from asyncio.exceptions import CancelledError
-except ImportError:  # pragma: no cover
-    from concurrent.futures import CancelledError
-
+import sys
+import warnings
+from contextlib import suppress
+from typing import Dict, Set
 from urllib.parse import urlparse
 
 import aiohttp
 
+if sys.version_info < (3, 8):  # pragma: no cover
+    from concurrent.futures import CancelledError
+else:
+    from asyncio.exceptions import CancelledError
+
 from . import data_processing, exceptions, general, oauth, utils
 from .api import APIPath, StreamingAPIPath
 from .commands import EventStreams, task
@@ -33,7 +35,7 @@ logger = logging.getLogger(__name__)
 
 class MetaPeonyClient(type):
 
-    def __new__(cls, name, bases, attrs, **kwargs):
+    def __new__(cls, name, bases, attrs, **_):
         """ put the :class:`~peony.commands.tasks.Task`s in the right place """
         tasks = {'tasks': set()}
 
@@ -93,6 +95,8 @@ class BasePeonyClient(metaclass=MetaPeonyClient):
         An event loop, if not specified :func:`asyncio.get_event_loop`
         is called
     """
+    _tasks: Dict[str, Set[task]]
+    _streams: EventStreams
 
     def __init__(self,
                  consumer_key=None,
@@ -409,7 +413,7 @@ class BasePeonyClient(metaclass=MetaPeonyClient):
     async def run_tasks(self):
         """ Run the tasks attached to the instance """
         tasks = self.get_tasks()
-        self._gathered_tasks = asyncio.gather(*tasks, loop=self.loop)
+        self._gathered_tasks = asyncio.gather(*tasks)
         try:
             await self._gathered_tasks
         except CancelledError:
@@ -614,8 +618,8 @@ class PeonyClient(BasePeonyClient):
     async def upload_media(self, file_,
                            media_type=None,
                            media_category=None,
-                           chunked=None,
-                           size_limit=3 * (1024**2),
+                           chunked=True,
+                           size_limit=None,
                            **params):
         """
             upload a media file on twitter
@@ -631,9 +635,6 @@ class PeonyClient(BasePeonyClient):
             ``media_type``
         chunked : bool, optional
             If True, force the use of the chunked upload for the media
-        size_limit : int, optional
-            If set, the media will be sent using a multipart upload if
-            its size is over ``size_limit`` bytes
         params : dict
             parameters used when making the request
 
@@ -656,16 +657,17 @@ class PeonyClient(BasePeonyClient):
                             "filename or binary data or an aiohttp request")
 
         media_size = await utils.get_size(media)
-        if chunked is not None:
-            size_test = False
-        else:
-            size_test = media_size > size_limit
+        if size_limit is not None:
+            warnings.warn("The size_limit parameter of upload_media is "
+                          "deprecated, chunked defaults to True and should be "
+                          "set explicitly to False if needed.",
+                          DeprecationWarning)
 
         if isinstance(media, aiohttp.ClientResponse):
             # send the content of the response
             media = media.content
 
-        if chunked or (size_test and chunked is None):
+        if chunked:
             args = media, media_size, file_, media_type, media_category
             response = await self._chunked_upload(*args, **params)
         else:
