@@ -4,14 +4,14 @@ import asyncio
 import logging
 import sys
 
-try:
-    from asyncio import CancelledError
-except ImportError:  # pragma: no cover
-    from concurrent.futures import CancelledError
-
 import aiohttp
 import async_timeout
 
+if sys.version_info < (3, 8):  # pragma: no cover
+    from concurrent.futures import CancelledError
+else:
+    from asyncio.exceptions import CancelledError
+
 from . import data_processing, exceptions, utils
 from .exceptions import StreamLimit
 from .general import rate_limit_notices
