@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import asyncio
 import logging
+import mimetypes
 import os
 import sys
 from functools import partial
@@ -13,13 +14,14 @@ import peony
 
 from . import exceptions
 
+mime = mimetypes.MimeTypes()
+
 try:
     import magic
-    mime = magic.Magic(mime=True)
+    magic_mime = magic.Magic(mime=True)
+    magic_module = True
 except Exception:  # pragma: no cover
-    import mimetypes
-    mime = mimetypes.MimeTypes()
-    magic = None
+    magic_module = False
 
 
 _logger = logging.getLogger(__name__)
@@ -108,7 +110,7 @@ class ErrorHandler(metaclass=MetaErrorHandler):
 
                 if status is not ErrorHandler.RETRY:
                     _logger.debug("raising exception")
-                    if future is not None:
+                    if future is not None and not future.done():
                         future.set_exception(exc)
                         return
 
@@ -294,12 +296,12 @@ async def get_type(media, path=None):
     str
         The category of the media on Twitter
     """
-    if magic:
+    if magic_module:
         if not media:
             raise TypeError("Media data is empty")
 
         _logger.debug("guessing mimetype using magic")
-        media_type = mime.from_buffer(media[:1024])
+        media_type = magic_mime.from_buffer(media[:1024])
     else:
         media_type = None
         if path:
